@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Text Segmentation Metrics
 #
-# Copyright (C) 2001-2015 NLTK Project
+# Copyright (C) 2001-2018 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com>
 #         David Doukhan <david.doukhan@gmail.com>
@@ -46,7 +46,8 @@ try:
 except ImportError:
     pass
 
-from nltk.compat import xrange
+from six.moves import range
+
 
 def windowdiff(seg1, seg2, k, boundary="1", weighted=False):
     """
@@ -213,7 +214,7 @@ def pk(ref, hyp, k=None, boundary='1'):
         k = int(round(len(ref) / (ref.count(boundary) * 2.)))
 
     err = 0
-    for i in xrange(len(ref)-k +1):
+    for i in range(len(ref)-k +1):
         r = ref[i:i+k].count(boundary) > 0
         h = hyp[i:i+k].count(boundary) > 0
         if r != h:
@@ -228,5 +229,3 @@ def setup_module(module):
         import numpy
     except ImportError:
         raise SkipTest("numpy is required for nltk.metrics.segmentation")
-
-
