@@ -2,7 +2,7 @@
 #
 # Author: Dan Garrette <dhgarrette@gmail.com>
 #
-# Copyright (C) 2001-2014 NLTK Project
+# Copyright (C) 2001-2018 NLTK Project
 # URL: <http://nltk.org>
 # For license information, see LICENSE.TXT
 
@@ -15,11 +15,13 @@ from __future__ import print_function, unicode_literals
 import re
 import operator
 from collections import defaultdict
-from functools import reduce
+from functools import reduce, total_ordering
 
+from six import string_types
+
+from nltk.util import Trie
 from nltk.internals import Counter
-from nltk.compat import (total_ordering, string_types,
-                         python_2_unicode_compatible)
+from nltk.compat import python_2_unicode_compatible
 
 APP = 'APP'
 
@@ -153,7 +155,7 @@ class LogicParser(object):
         """Split the data into tokens"""
         out = []
         mapping = {}
-        tokenTrie = StringTrie(self.get_all_symbols())
+        tokenTrie = Trie(self.get_all_symbols())
         token = ''
         data_idx = 0
         token_start_idx = data_idx
@@ -176,7 +178,7 @@ class LogicParser(object):
                     c = data[data_idx+len(symbol)]
                 else:
                     break
-            if StringTrie.LEAF in st:
+            if Trie.LEAF in st:
                 #token is a complete symbol
                 if token:
                     mapping[len(out)] = token_start_idx
@@ -801,7 +803,7 @@ def read_type(type_string):
 
 class TypeException(Exception):
     def __init__(self, msg):
-        Exception.__init__(self, msg)
+        super(TypeException, self).__init__(msg)
 
 class InconsistentTypeHierarchyException(TypeException):
     def __init__(self, variable, expression=None):
@@ -811,21 +813,20 @@ class InconsistentTypeHierarchyException(TypeException):
         else:
             msg = "The variable '%s' was found in multiple places with different"\
                 " types." % (variable)
-        Exception.__init__(self, msg)
+        super(InconsistentTypeHierarchyException, self).__init__(msg)
 
 class TypeResolutionException(TypeException):
     def __init__(self, expression, other_type):
-        Exception.__init__(self, "The type of '%s', '%s', cannot be "
-                           "resolved with type '%s'" % \
-                           (expression, expression.type, other_type))
+        super(TypeResolutionException, self).__init__(
+            "The type of '%s', '%s', cannot be resolved with type '%s'" %
+            (expression, expression.type, other_type))
 
 class IllegalTypeException(TypeException):
     def __init__(self, expression, other_type, allowed_type):
-        Exception.__init__(self, "Cannot set type of %s '%s' to '%s'; "
-                           "must match type '%s'." %
-                           (expression.__class__.__name__, expression,
-                            other_type, allowed_type))
-
+        super(IllegalTypeException, self).__init__(
+            "Cannot set type of %s '%s' to '%s'; must match type '%s'." %
+            (expression.__class__.__name__, expression, other_type,
+            allowed_type))
 
 def typecheck(expressions, signature=None):
     """
@@ -1788,23 +1789,6 @@ class EqualityExpression(BinaryExpression):
 
 ### Utilities
 
-class StringTrie(defaultdict):
-    LEAF = "<leaf>"
-
-    def __init__(self, strings=None):
-        defaultdict.__init__(self, StringTrie)
-        if strings:
-            for string in strings:
-                self.insert(string)
-
-    def insert(self, string):
-        if len(string):
-            self[string[0]].insert(string[1:])
-        else:
-            #mark the string is complete
-            self[StringTrie.LEAF] = None
-
-
 class LogicalExpressionException(Exception):
     def __init__(self, index, message):
         self.index = index
@@ -1890,7 +1874,7 @@ def demo():
     print(lexpr(r'(\P.\Q.exists x.(P(x) & Q(x)))(\x.dog(x))(\x.bark(x))').simplify())
 
     print('='*20 + 'Test alpha conversion and binder expression equality' + '='*20)
-    e1 = p('exists x.P(x)')
+    e1 = lexpr('exists x.P(x)')
     print(e1)
     e2 = e1.alpha_convert(Variable('z'))
     print(e2)
@@ -1923,4 +1907,4 @@ def printtype(ex):
 
 if __name__ == '__main__':
     demo()
-    demo_errors()
+#    demo_errors()
